@@ -1,27 +1,33 @@
 package org.gcube.applicationsupportlayer.social;
 
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
 import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.List;
+import java.util.Properties;
 import java.util.UUID;
 
 import org.gcube.application.framework.core.session.ASLSession;
 import org.gcube.applicationsupportlayer.social.mailing.EmailPlugin;
-import org.gcube.common.core.utils.logging.GCUBEClientLog;
+import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
+import org.gcube.common.homelibrary.home.workspace.WorkspaceItem;
+import org.gcube.common.homelibrary.home.workspace.WorkspaceSharedFolder;
+import org.gcube.portal.custom.communitymanager.OrganizationsUtil;
 import org.gcube.portal.databook.shared.ApplicationProfile;
 import org.gcube.portal.databook.shared.Notification;
 import org.gcube.portal.databook.shared.NotificationChannelType;
 import org.gcube.portal.databook.shared.NotificationType;
 import org.gcube.portal.databook.shared.RunningJob;
-import org.gcube.portlets.user.homelibrary.home.exceptions.InternalErrorException;
-import org.gcube.portlets.user.homelibrary.home.workspace.WorkspaceFolder;
-import org.gcube.portlets.user.homelibrary.home.workspace.WorkspaceItem;
 import org.gcube.vomanagement.usermanagement.UserManager;
 import org.gcube.vomanagement.usermanagement.exception.UserManagementPortalException;
 import org.gcube.vomanagement.usermanagement.exception.UserManagementSystemException;
 import org.gcube.vomanagement.usermanagement.exception.UserRetrievalFault;
 import org.gcube.vomanagement.usermanagement.impl.liferay.LiferayUserManager;
 import org.gcube.vomanagement.usermanagement.model.UserModel;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * 
@@ -30,13 +36,21 @@ import org.gcube.vomanagement.usermanagement.model.UserModel;
  * use to notify users from within your application 
  */
 public class ApplicationNotificationsManager extends SocialPortalBridge implements NotificationsManager {
-	static GCUBEClientLog _log = new GCUBEClientLog(ApplicationNotificationsManager.class);
+	private static final Logger _log = LoggerFactory.getLogger(ApplicationNotificationsManager.class);
+
+	private static final String SENDER_EMAIL = "notificationSenderEmail";
+	private static final String GATEWAY_NAME = "portalinstancename";
+
+	private String portalName;
+	private String senderEmail;
 	/**
 	 * Use this constructor if you do not need notifications to point back to your applications
 	 * @param aslSession the ASLSession instance
 	 */
 	public ApplicationNotificationsManager(ASLSession session) {
 		super(session);
+		portalName = getPortalInstanceName();
+		senderEmail = getNotificationSenderEmail();
 		_log.warn("Asked for Simple Notification (without redirect to creator)");
 	}
 	/**
@@ -50,6 +64,8 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 */
 	public ApplicationNotificationsManager(ASLSession session, String portletClassName) {
 		super(session, portletClassName);
+		portalName = getPortalInstanceName();
+		senderEmail = getNotificationSenderEmail();
 	}
 	/**
 	 * actually save the notification to the store
@@ -77,7 +93,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				_log.error("Error While trying to save Notification");
 		}
 		if (channels.contains(NotificationChannelType.EMAIL))
-			EmailPlugin.sendNotification(notification2Save, aslSession.getGroupName());
+			EmailPlugin.getInstance().sendNotification(notification2Save, aslSession.getGroupName(), portalName, senderEmail);
 
 		if (channels.isEmpty()) {
 			_log.info("Notification was not needed as "+ notification2Save.getUserid()  +" decided not to be notified for " + notification2Save.getType());
@@ -91,24 +107,35 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @return .
 	 */
 	private String getApplicationUrl() {
-		if (applicationProfile != null && applicationProfile.getUrl() != null)
-			return applicationProfile.getUrl();
-		else return "";
+		if (applicationProfile != null && applicationProfile.getUrl() != null) {
+			_log.trace("getApplicationUrl="+applicationProfile.getUrl());
+			return applicationProfile.getUrl();			
+		}
+		else {
+			_log.warn("applicationProfile NULL or url is empty");
+			return "";
+		}
 	}
 	/**
 	 * {@inheritDoc}
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyFolderSharing(String userIdToNotify, WorkspaceFolder sharedFolder) throws InternalErrorException {
+	public boolean notifyFolderSharing(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws InternalErrorException {
+		String sharedFolderName = sharedFolder.getName();
+		if (sharedFolder.isShared()) {
+			WorkspaceSharedFolder sharedWSFolder = (WorkspaceSharedFolder) sharedFolder;
+			if (sharedWSFolder.isVreFolder())
+				sharedFolderName = sharedWSFolder.getDisplayName(); 
+		}
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_FOLDER_SHARE, 
 				userIdToNotify, //user no notify
-				sharedFolder.getId(),  //the 
+				sharedFolder.getId(),  
 				new Date(),
 				getApplicationUrl()+"?itemid="+sharedFolder.getId(), 
-				"shared the workspace folder "+ sharedFolder.getName() +" with you",
+				"shared the workspace folder \""+ sharedFolderName +"\" with you",
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -116,6 +143,72 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 
 		return saveNotification(not);
 	}
+	/**
+	 * {@inheritDoc}
+	 * @throws Exception 
+	 */
+	@Override
+	public boolean notifyFolderUnsharing(String userIdToNotify,	 String unsharedFolderId, String unsharedFolderName) throws Exception {
+		Notification not = new Notification(
+				UUID.randomUUID().toString(), 
+				NotificationType.WP_FOLDER_UNSHARE, 
+				userIdToNotify, //user no notify
+				unsharedFolderId, 
+				new Date(),
+				getApplicationUrl()+"?itemid="+unsharedFolderId, 
+				"unshared the workspace folder \""+ unsharedFolderName+"\"",
+				false, 
+				aslSession.getUsername(),
+				aslSession.getUserFullName(), 
+				aslSession.getUserAvatarId());
+
+		return saveNotification(not);
+	}
+	/**
+	 * {@inheritDoc}
+	 * @throws Exception 
+	 */
+	@Override
+	public boolean notifyAdministratorUpgrade(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws Exception {
+		String sharedFolderName = sharedFolder.getName();
+		Notification not = new Notification(
+				UUID.randomUUID().toString(), 
+				NotificationType.WP_ADMIN_UPGRADE, 
+				userIdToNotify, //user no notify
+				sharedFolder.getId(),   
+				new Date(),
+				getApplicationUrl()+"?itemid="+sharedFolder.getId(),  
+				"upgraded you to Administrator of the workspace folder \""+ sharedFolderName+"\"",
+				false, 
+				aslSession.getUsername(),
+				aslSession.getUserFullName(), 
+				aslSession.getUserAvatarId());
+
+		return saveNotification(not);
+	}
+	/**
+	 * {@inheritDoc}
+	 * @throws Exception 
+	 */
+	@Override
+	public boolean notifyAdministratorDowngrade(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws Exception {
+		String sharedFolderName = sharedFolder.getName();
+		Notification not = new Notification(
+				UUID.randomUUID().toString(), 
+				NotificationType.WP_ADMIN_DOWNGRADE, 
+				userIdToNotify, //user no notify
+				sharedFolder.getId(),   
+				new Date(),
+				getApplicationUrl()+"?itemid="+sharedFolder.getId(),  
+				"downgraded you from Administrator of the workspace folder \""+ sharedFolderName+"\"",
+				false, 
+				aslSession.getUsername(),
+				aslSession.getUserFullName(), 
+				aslSession.getUserAvatarId());
+
+		return saveNotification(not);
+	}
+	
 	/**
 	 * {@inheritDoc}
 	 * @throws InternalErrorException 
@@ -129,7 +222,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				renamedFolderId,  //the 
 				new Date(),
 				getApplicationUrl()+"?itemid="+renamedFolderId, 
-				"renamed your shared folder "+ previousName +" as " + newName,
+				"renamed your shared folder \""+ previousName +"\" as \"" + newName+"\"",
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -144,7 +237,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws UserManagementSystemException 
 	 */
 	@Override
-	public boolean notifyFolderAddedUser(String userIdToNotify, WorkspaceFolder sharedFolder, String newAddedUserId) throws InternalErrorException, UserManagementSystemException, UserRetrievalFault, UserManagementPortalException {
+	public boolean notifyFolderAddedUser(String userIdToNotify, WorkspaceSharedFolder sharedFolder, String newAddedUserId) throws InternalErrorException, UserManagementSystemException, UserRetrievalFault, UserManagementPortalException {
 		UserManager um = new LiferayUserManager();
 		UserModel user = um.getUserByScreenName(newAddedUserId);
 		Notification not = new Notification(
@@ -154,7 +247,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				sharedFolder.getId(),  //the 
 				new Date(),
 				getApplicationUrl()+"?itemid="+sharedFolder.getId(),
-				"added "+ user.getFullname() +" to your workspace shared folder "+ sharedFolder.getName(),
+				"added "+ user.getFullname() +" to your workspace shared folder \""+ sharedFolder.getName()+"\"",
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -169,7 +262,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws UserManagementSystemException 
 	 */
 	@Override
-	public boolean notifyFolderAddedUsers(String userIdToNotify, WorkspaceFolder sharedFolder, List<String> newAddedUserIds) throws InternalErrorException, UserManagementSystemException, UserRetrievalFault, UserManagementPortalException  {
+	public boolean notifyFolderAddedUsers(String userIdToNotify, WorkspaceSharedFolder sharedFolder, List<String> newAddedUserIds) throws InternalErrorException, UserManagementSystemException, UserRetrievalFault, UserManagementPortalException  {
 		if (newAddedUserIds != null && newAddedUserIds.size() > 0) {
 			if (newAddedUserIds.size() == 1)
 				return notifyFolderAddedUser(userIdToNotify, sharedFolder, newAddedUserIds.get(0));
@@ -185,7 +278,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 					sharedFolder.getId(),  //the 
 					new Date(),
 					getApplicationUrl()+"?itemid="+sharedFolder.getId(),
-					"added "+ addedUsersFullNames +" to your workspace shared folder "+ sharedFolder.getName(),
+					"added "+ addedUsersFullNames +" to your workspace shared folder \""+ sharedFolder.getName()+"\"",
 					false, 
 					aslSession.getUsername(),
 					aslSession.getUserFullName(), 
@@ -200,7 +293,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyFolderRemovedUser(String userIdToNotify, WorkspaceFolder sharedFolder) throws InternalErrorException, UserManagementSystemException, UserRetrievalFault, UserManagementPortalException {
+	public boolean notifyFolderRemovedUser(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws InternalErrorException, UserManagementSystemException, UserRetrievalFault, UserManagementPortalException {
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_FOLDER_REMOVEDUSER, 
@@ -208,7 +301,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				sharedFolder.getId(),  //the 
 				new Date(),
 				getApplicationUrl()+"?itemid="+sharedFolder.getId(), 
-				"unshared his shared folder "+ sharedFolder.getName() + " from your workspace",
+				"unshared his shared folder \""+ sharedFolder.getName() + "\" from your workspace",
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -221,7 +314,11 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyAddedItem(String userIdToNotify, WorkspaceItem item, WorkspaceFolder sharedFolder) throws InternalErrorException {
+	public boolean notifyAddedItem(String userIdToNotify, WorkspaceItem item, WorkspaceSharedFolder sharedFolder) throws InternalErrorException {
+		String notifyText = sharedFolder.isVreFolder() ? 
+				"added "+ item.getName() +" to the workspace group folder " + sharedFolder.getDisplayName() :
+			"added "+ item.getName() +" to your workspace shared folder "+ item.getPath().substring(0,item.getPath().lastIndexOf('/'));
+		
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_ITEM_NEW, 
@@ -229,7 +326,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				item.getId(),  //the 
 				new Date(),
 				getApplicationUrl()+"?itemid="+item.getParent().getId(), 
-				"added "+ item.getName() +" to your workspace shared folder "+ sharedFolder.getName(),
+				notifyText,
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -242,7 +339,10 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyMovedItem(String userIdToNotify,	WorkspaceItem item, WorkspaceFolder sharedFolder) throws InternalErrorException {
+	public boolean notifyMovedItem(String userIdToNotify, WorkspaceItem item, WorkspaceSharedFolder sharedFolder) throws InternalErrorException {
+		String notifyText = sharedFolder.isVreFolder() ? "removed item  "+ item.getName() +" from the workspace group folder " + sharedFolder.getDisplayName():
+			"removed item "+ item.getName() +" from your workspace shared folder \""+ sharedFolder.getName()+"\"";
+		
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_ITEM_DELETE, 
@@ -250,7 +350,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				item.getId(),  //the 
 				new Date(),
 				getApplicationUrl()+"?itemid="+sharedFolder.getId(), 
-				"removed item "+ item.getName() +" from your workspace shared folder "+ sharedFolder.getName(),
+				notifyText,
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -263,7 +363,10 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyRemovedItem(String userIdToNotify, String itemName, WorkspaceFolder sharedFolder) throws InternalErrorException {
+	public boolean notifyRemovedItem(String userIdToNotify, String itemName, WorkspaceSharedFolder sharedFolder) throws InternalErrorException {
+		String notifyText = sharedFolder.isVreFolder() ? "deleted item  \""+ itemName +"\" from the workspace group folder " + sharedFolder.getDisplayName():
+			" deleted item \""+ itemName +"\" from your workspace shared folder \""+ sharedFolder.getName()+"\"";
+
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_ITEM_DELETE, 
@@ -271,7 +374,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				sharedFolder.getId(),  //the 
 				new Date(),
 				getApplicationUrl()+"?itemid="+sharedFolder.getId(), 
-				"deleted item "+ itemName +" from your workspace shared folder "+ sharedFolder.getName(),
+				notifyText,
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -284,7 +387,10 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyUpdatedItem(String userIdToNotify,	WorkspaceItem item, WorkspaceFolder sharedFolder) throws InternalErrorException {
+	public boolean notifyUpdatedItem(String userIdToNotify,	WorkspaceItem item, WorkspaceSharedFolder sharedFolder) throws InternalErrorException {
+		String notifyText = sharedFolder.isVreFolder() ? " updated  \""+ item.getName() +"\" from the workspace group folder \"" + sharedFolder.getDisplayName()+"\"":
+			" updated \""+ item.getName() +"\" to your workspace shared folder \""+ item.getPath().substring(0,item.getPath().lastIndexOf('/'))+"\"";
+
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_ITEM_UPDATED, 
@@ -292,7 +398,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				item.getId(),  //the 
 				new Date(),
 				getApplicationUrl()+"?itemid="+item.getParent().getId(), 
-				" updated "+ item.getName() +" to your workspace shared folder "+ item.getParent().getName(),
+				notifyText,
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -305,7 +411,10 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyItemRenaming(String userIdToNotify, String previousName, WorkspaceItem renamedItem) throws InternalErrorException {
+	public boolean notifyItemRenaming(String userIdToNotify, String previousName, WorkspaceItem renamedItem,  WorkspaceSharedFolder rootSharedFolder) throws InternalErrorException {
+		String notifyText = rootSharedFolder.isVreFolder() ? "renamed \""+ previousName +"\" as \"" + renamedItem.getName() +"\" in the workspace group folder " + rootSharedFolder.getDisplayName():
+			"renamed \"" + previousName +"\" as \"" + renamedItem.getName() +"\" in your shared folder \"" + renamedItem.getPath().substring(0, renamedItem.getPath().lastIndexOf('/'))+"\"";
+
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_ITEM_RENAMED, 
@@ -313,7 +422,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				renamedItem.getId(),  //the 
 				new Date(),
 				getApplicationUrl()+"?itemid="+renamedItem.getParent().getId(), 
-				"renamed " + previousName +" as " + renamedItem.getName() +" in your shared folder " + renamedItem.getParent().getName(),
+				notifyText,
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -345,6 +454,31 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
+	public boolean notifyPost(String userIdToNotify, String feedid,	String feedText) {
+
+		StringBuilder notificationText = new StringBuilder();
+		notificationText.append("posted a news on <b>").append(aslSession.getGroupName()).append(":</b>") // has done something
+		.append("<br /><br /> ").append(escapeHtml(feedText)).append(". ")
+		.append("<br /><br />Follow the discussion and comment it. ");
+
+		Notification not = new Notification(
+				UUID.randomUUID().toString(), 
+				NotificationType.POST_ALERT, 
+				userIdToNotify, //user no notify
+				feedid,  //the post 
+				new Date(),
+				getApplicationUrl()+"?oid="+feedid, 
+				notificationText.toString(),
+				false, 
+				aslSession.getUsername(),
+				aslSession.getUserFullName(), 
+				aslSession.getUserAvatarId());
+		return saveNotification(not);
+	}
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
 	public boolean notifyOwnCommentReply(String userIdToNotify, String feedid, String feedText) {
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
@@ -364,8 +498,8 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyCommentReply(String userIdToNotify, String feedid, String commentText, String feedOwnerFullName) {
-		String notificationText =  (aslSession.getUserFullName().compareTo(feedOwnerFullName) == 0) ? 
+	public boolean notifyCommentReply(String userIdToNotify, String feedid, String commentText, String feedOwnerFullName, String feedOwnerId) {
+		String notificationText =  (aslSession.getUsername().compareTo(feedOwnerId) == 0) ? 
 				"also commented on his post: " + escapeHtml(commentText)
 				: 
 					"also commented on " + feedOwnerFullName + "'s post: " + escapeHtml(commentText);
@@ -414,7 +548,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				feedid,  //the post 
 				new Date(),
 				"/group/data-e-infrastructure-gateway?oid="+feedid, 
-				"mentioned you in his post: " + escapeHtml(feedText),
+				"mentioned you: " + escapeHtml(feedText),
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -433,7 +567,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				feedid,  //the post 
 				new Date(),
 				"/group/data-e-infrastructure-gateway?oid="+feedid, 
-				"likes your post: " + escapeHtml(feedText),
+				"favorited your post: " + escapeHtml(feedText),
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -583,18 +717,18 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	@Override
 	public boolean notifyNewCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate) {
 		SimpleDateFormat spf = new SimpleDateFormat("EEE dd MMMMM, yyyy");
-		
+
 		String endDateToDisplay="";
 		if (endingDate != null) {
 			endDateToDisplay = " to " + spf.format(endingDate);
 		}
-	
+
 		StringBuilder notificationText = new StringBuilder();
 		notificationText.append("added the following event in the <b>").append(aslSession.getGroupName()).append("</b> shared calendar: ") // has done something
 		.append("<strong>").append(eventTitle).append("</strong><br />")
 		.append("<br /><strong> Time:</strong> ").append(spf.format(startDate)).append(endDateToDisplay).append("<br />")
 		.append("<br /><strong> Category: </strong> ").append(eventType);
-		
+
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.CALENDAR_ADDED_EVENT, 
@@ -610,4 +744,124 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 
 		return saveNotification(not);
 	}
+
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
+	public boolean notifyEditedCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate) {
+		SimpleDateFormat spf = new SimpleDateFormat("EEE dd MMMMM, yyyy");
+
+		String endDateToDisplay="";
+		if (endingDate != null) {
+			endDateToDisplay = " to " + spf.format(endingDate);
+		}
+
+		StringBuilder notificationText = new StringBuilder();
+		notificationText.append("edited the following event in the <b>").append(aslSession.getGroupName()).append("</b> shared calendar: ") // has done something
+		.append("<strong>").append(eventTitle).append("</strong><br />")
+		.append("<br /><strong> Time:</strong> ").append(spf.format(startDate)).append(endDateToDisplay).append("<br />")
+		.append("<br /><strong> Category: </strong> ").append(eventType);
+
+		Notification not = new Notification(
+				UUID.randomUUID().toString(), 
+				NotificationType.CALENDAR_UPDATED_EVENT, 
+				userIdToNotify, //user no notify
+				"",  //
+				new Date(),
+				getApplicationUrl(), 
+				notificationText.toString(),
+				false, 
+				aslSession.getUsername(),
+				aslSession.getUserFullName(), 
+				aslSession.getUserAvatarId());
+
+		return saveNotification(not);
+	}
+
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
+	public boolean notifyDeletedCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate) {
+		SimpleDateFormat spf = new SimpleDateFormat("EEE dd MMMMM, yyyy");
+
+		String endDateToDisplay="";
+		if (endingDate != null) {
+			endDateToDisplay = " to " + spf.format(endingDate);
+		}
+
+		StringBuilder notificationText = new StringBuilder();
+		notificationText.append("deleted the following event in the <b>").append(aslSession.getGroupName()).append("</b> shared calendar: ") // has done something
+		.append("<strong>").append(eventTitle).append("</strong><br />")
+		.append("<br /><strong> Was planned:</strong> ").append(spf.format(startDate)).append(endDateToDisplay).append("<br />")
+		.append("<br /><strong> Category: </strong> ").append(eventType);
+
+		Notification not = new Notification(
+				UUID.randomUUID().toString(), 
+				NotificationType.CALENDAR_DELETED_EVENT, 
+				userIdToNotify, //user no notify
+				"",  //
+				new Date(),
+				getApplicationUrl(), 
+				notificationText.toString(),
+				false, 
+				aslSession.getUsername(),
+				aslSession.getUserFullName(), 
+				aslSession.getUserAvatarId());
+
+		return saveNotification(not);
+	}	
+
+	/**
+	 * read the portal instance name from a property file and returns it
+	 */
+	private static String getPortalInstanceName() {
+		//get the portles to look for from the property file
+		Properties props = new Properties();
+		String toReturn = "";
+
+		try {
+			String propertyfile = OrganizationsUtil.getTomcatFolder()+"conf/gcube-data.properties";			
+			File propsFile = new File(propertyfile);
+			FileInputStream fis = new FileInputStream(propsFile);
+			props.load( fis);
+			toReturn = props.getProperty(GATEWAY_NAME);
+		}
+		//catch exception in case properties file does not exist
+		catch(IOException e) {
+			toReturn = "D4science Gateway";
+			_log.error("gcube-data.properties file not found under $CATALINA_HOME/conf dir, returning default Portal Name " + toReturn);
+			return toReturn;
+		}
+		_log.debug("Returning Gateway Name: " + toReturn );
+		return toReturn;
+	}
+
+	/**
+	 * read the sender email for notifications name from a property file and returns it
+	 */
+	private static String getNotificationSenderEmail() {
+		//get the portles to look for from the property file
+		Properties props = new Properties();
+		String toReturn = "";
+
+		try {
+			String propertyfile = OrganizationsUtil.getTomcatFolder()+"conf/gcube-data.properties";			
+			File propsFile = new File(propertyfile);
+			FileInputStream fis = new FileInputStream(propsFile);
+			props.load( fis);
+			toReturn = props.getProperty(SENDER_EMAIL);
+		}
+		//catch exception in case properties file does not exist
+		catch(IOException e) {
+			toReturn = "do-not-reply@d4science.org";
+			_log.error("gcube-data.properties file not found under $CATALINA_HOME/conf dir, returning default Email" + toReturn);
+			return toReturn;
+		}
+		_log.debug("Returning SENDER_EMAIL: " + toReturn );
+		return toReturn;
+	}
+
+
 }
